@@ -2,11 +2,11 @@
 
 import jaraco.abode.helpers.constants as CONST
 
-import tests.mock.login as LOGIN
-import tests.mock.oauth_claims as OAUTH_CLAIMS
-import tests.mock.logout as LOGOUT
-import tests.mock.panel as PANEL
-import tests.mock.devices.lm as LM
+from .mock import login as LOGIN
+from .mock import oauth_claims as OAUTH_CLAIMS
+from .mock import logout as LOGOUT
+from .mock import panel as PANEL
+from .mock.devices import lm as LM
 
 
 class TestLM:
